#[non_exhaustive]pub struct PacketMeta {}Expand description
Metadata associated to a packet.
The packet metadata is a set of attributes associated to network packets
as they travel up or down the stack. The metadata is get/set by the
Driver implementations or by the user when sending/receiving packets from a
socket.
Metadata fields are enabled via Cargo features. If no field is enabled, this struct becomes zero-sized, which allows the compiler to optimize it out as if the packet metadata mechanism didn’t exist at all.
This struct is marked as #[non_exhaustive]. This means it is not possible to
create it directly by specifying all fields. You have to instead create it with
default values and then set the fields you want. This makes adding metadata
fields a non-breaking change.
let mut meta = xarxa_driver::PacketMeta::default();
#[cfg(feature = "packetmeta-id")]
{
meta.id = 15;
}Trait Implementations
Sourceimpl Clone for PacketMeta
impl Clone for PacketMeta
Sourcefn clone(&self) -> PacketMeta
fn clone(&self) -> PacketMeta
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PacketMeta
Sourceimpl Debug for PacketMeta
impl Debug for PacketMeta
Sourceimpl Default for PacketMeta
impl Default for PacketMeta
Sourcefn default() -> PacketMeta
fn default() -> PacketMeta
Returns the “default value” for a type. Read more
impl Eq for PacketMeta
Sourceimpl Format for PacketMeta
impl Format for PacketMeta
Sourceimpl Hash for PacketMeta
impl Hash for PacketMeta
Sourceimpl PartialEq for PacketMeta
impl PartialEq for PacketMeta
impl StructuralPartialEq for PacketMeta