pub struct TxTimestamp {
pub id: u32,
pub timestamp: Timestamp,
}Expand description
The timestamp of a transmitted packet, reported by [Device::poll_tx_timestamp].
Fields
id: u32The [PacketMeta::id] of the packet this timestamp belongs to.
timestamp: TimestampThe time at which the packet was transmitted, as measured by the device.